<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl" sourcelanguage="en">
<context>
    <name>Bubble</name>
    <message>
        <location filename="../dde-osd/src/notification/bubble.cpp" line="325"/>
        <source>1 new message</source>
        <translation>1 nowa wiadomość</translation>
    </message>
</context>
<context>
    <name>BubbleItem</name>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="232"/>
        <source>Just Now</source>
        <translation>Właśnie teraz</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="234"/>
        <source>%1 minutes ago</source>
        <translation>%1 minut temu</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="236"/>
        <source>%1 hours ago</source>
        <translation>%1 godzin temu</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="239"/>
        <source>Yesterday </source>
        <translation>Wczoraj </translation>
    </message>
</context>
<context>
    <name>Content</name>
    <message>
        <location filename="../dde-license-dialog/src/content.cpp" line="272"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../dde-license-dialog/src/content.cpp" line="273"/>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
</context>
<context>
    <name>DMemoryWarningDialog</name>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="49"/>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="88"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="51"/>
        <source>Release</source>
        <translation>Wydanie</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="55"/>
        <source>This application will be ended, please make sure your data has been saved!</source>
        <translation>Aplikacja zostanie zakończona, upewnij się że wszystkie dane zostały zapisane!</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="56"/>
        <source>Please save your document, text and spreadsheet</source>
        <translation>Prosimy o zapisanie swoich dokumentów, tekstów lub arkuszy</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="89"/>
        <source>Continue</source>
        <translation>Kontynuuj</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="110"/>
        <source>Insufficient system memory, please end some applications to avoid getting stuck.</source>
        <translation>Za mało pamięci systemowej, zakończ niepotrzebne aplikacje, aby uniknąć zawieszenia systemu.</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="222"/>
        <source>Continue to run %1, %2MB memory is required</source>
        <translation>Kontynuuj, aby uruchomić %1, wymagane jest %2 MB pamięci</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="225"/>
        <source>Continue to open browser tab, %1MB memory is required</source>
        <translation>Kontynuuj, aby otworzyć kartę w przeglądarce, wymagane jest %1 pamięci</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="228"/>
        <source>To continue the operation, %1MB memory is required</source>
        <translation>Aby kontynuować działanie wymagane jest %1 MB pamięci</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="234"/>
        <source>Your current memory is sufficient enough, continue to run %1?</source>
        <translation>Twoja bieżąca ilość pamięci jest wystarczająca, kontynuować uruchomienie %1?</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="237"/>
        <source>Your current memory is sufficient enough, continue to open browser tab?</source>
        <translation>Twoja bieżąca ilość pamięci jest wystarczająca, kontynuować otwieranie karty przeglądarki?</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="240"/>
        <source>Your current memory is sufficient enough, continue the operation?</source>
        <translation>Twoja bieżąca ilość pamięci jest wystarczająca, kontynuować działanie?</translation>
    </message>
</context>
<context>
    <name>DisplayModeProvider</name>
    <message>
        <location filename="../dde-osd/src/displaymodeprovider.cpp" line="292"/>
        <source>Only on %1</source>
        <translation>Tylko na %1</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/displaymodeprovider.cpp" line="294"/>
        <source>Duplicate</source>
        <translation>Duplikuj</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/displaymodeprovider.cpp" line="296"/>
        <source>Extend</source>
        <translation>Rozszerz</translation>
    </message>
</context>
<context>
    <name>KBLayoutIndicator</name>
    <message>
        <location filename="../dde-osd/src/kblayoutindicator.cpp" line="161"/>
        <source>Add keyboard layout</source>
        <translation>Dodaj układ klawiatury</translation>
    </message>
</context>
<context>
    <name>NetworkSecretDialog</name>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="107"/>
        <source>Password required to connect &lt;font color=&quot;%1&quot;&gt;%2&lt;/font&gt;</source>
        <translation>Do połączenia wymagane jest hasło &lt;font color=&quot;%1&quot;&gt;%2&lt;/font&gt;</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="179"/>
        <source>Wrong password, please enter again!</source>
        <translation>Błędne hasło, spróbuj ponownie!</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="116"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="116"/>
        <source>Connect</source>
        <translation>Połącz</translation>
    </message>
</context>
<context>
    <name>NotifyCenterWidget</name>
    <message>
        <location filename="../dde-osd/src/notification-center/notifycenterwidget.cpp" line="97"/>
        <source>Notification Center</source>
        <translation>Centrum powiadomień</translation>
    </message>
</context>
<context>
    <name>NotifyWidget</name>
    <message>
        <location filename="../dde-osd/src/notification-center/notifywidget.cpp" line="40"/>
        <source>No system notifications</source>
        <translation>Brak powiadomień systemowych</translation>
    </message>
</context>
<context>
    <name>OSDProvider</name>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="138"/>
        <source>Fn toggle</source>
        <translation>Przełącznik Fn</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="125"/>
        <source>WLAN on</source>
        <translation>WLAN włączony</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="126"/>
        <source>WLAN off</source>
        <translation>WLAN wyłączony</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="128"/>
        <source>Caps Lock on</source>
        <translation>Caps Lock włączony</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="129"/>
        <source>Caps Lock off</source>
        <translation>Caps Lock wyłączony</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="131"/>
        <source>Numeric keypad on</source>
        <translation>Klawiatura numeryczna włączona</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="132"/>
        <source>Numeric keypad off</source>
        <translation>Klawiatura numeryczna wyłączona</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="134"/>
        <source>Touchpad on</source>
        <translation>Panel dotykowy włączony</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="135"/>
        <source>Touchpad off</source>
        <translation>Panel dotykowy wyłączony</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="136"/>
        <source>Touchpad toggle</source>
        <translation>Przełącznik Touchpada</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="140"/>
        <source>Airplane mode on</source>
        <translation>Tryb samolotowy włączony</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="141"/>
        <source>Airplane mode off</source>
        <translation>Tryb samolotowy wyłączony</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="143"/>
        <source>Mute on</source>
        <translation>Wyciszenie włączone</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="144"/>
        <source>Mute off</source>
        <translation>Wyciszenie wyłączone</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="146"/>
        <source>Balanced power</source>
        <translation>Zasilanie zrównoważone</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="147"/>
        <source>Power saver</source>
        <translation>Oszczędność energii</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="148"/>
        <source>High performance</source>
        <translation>Wysoka wydajność</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="150"/>
        <source>Window effect enabled</source>
        <translation>Włączono efekty okna</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="151"/>
        <source>Window effect disabled</source>
        <translation>Wyłączono efekty okna</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="152"/>
        <source>Failed to enable window effects</source>
        <translation>Nie udało się włączyć efektów okna</translation>
    </message>
</context>
<context>
    <name>PasswordWidget</name>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="57"/>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="146"/>
        <source>Passwords do not match</source>
        <translation>Hasła nie pasują do siebie</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="65"/>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation>Wskazówka będzie widoczna dla wszystkich użytkowników. Nie wprowadzaj tutaj swojego hasła.</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="86"/>
        <source>New Password</source>
        <translation>Nowe hasło</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="120"/>
        <source>Repeat Password</source>
        <translation>Powtórz hasło</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="128"/>
        <source>Password Hint</source>
        <translation>Wskazówka do hasła</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="137"/>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="138"/>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="139"/>
        <source>Optional</source>
        <translation>Opcjonalne</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="221"/>
        <source>Strong</source>
        <translation>Silne</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="231"/>
        <source>Medium</source>
        <translation>Średnie</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="240"/>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="253"/>
        <source>A stronger password is recommended: more than 8 characters, and contains 3 of the four character types: lowercase letters, uppercase letters, numbers, and symbols.</source>
        <translation>Zalecamy użycie silniejszego hasła: dłuższe niż 8 znaków, zwierające 3 z czterech typów znaków: małe litery, duże litery, cyfry i symbole</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="244"/>
        <source>Weak</source>
        <translation>Słabe</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="255"/>
        <source>Error occurred when reading the configuration files of password rules!</source>
        <translation>Nastąpił błąd podczas wczytywania pliku konfiguracyjnego zawierającego reguły haseł!</translation>
    </message>
</context>
<context>
    <name>PinCodeDialog</name>
    <message>
        <location filename="../dde-bluetooth-dialog/src/pincodedialog.cpp" line="40"/>
        <source>The PIN for connecting to the Bluetooth device is:</source>
        <translation>Kod PIN do połączenia z urządzeniem Bluetooth to:</translation>
    </message>
    <message>
        <location filename="../dde-bluetooth-dialog/src/pincodedialog.cpp" line="49"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../dde-bluetooth-dialog/src/pincodedialog.cpp" line="51"/>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
</context>
<context>
    <name>ProcessInfoModel</name>
    <message>
        <location filename="../dmemory-warning-dialog/src/processinfomodel.cpp" line="111"/>
        <source>End</source>
        <translation>Zakończ</translation>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="76"/>
        <source>Password cannot be empty</source>
        <translation>Hasło nie może być puste</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="77"/>
        <source>Password must have at least %1 characters</source>
        <translation>Hasło musi zawierać co najmniej %1 znaków</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="78"/>
        <source>Password must be no more than %1 characters</source>
        <translation>Hasło nie może przekraczać %1 znaków</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="79"/>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>Hasło musi zawierać tylko litery angielskie (z rozróżnieniem wielkich i małych), cyfry lub symbole specjalne (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="80"/>
        <source>No more than %1 palindrome characters please</source>
        <translation>Nie więcej niż %1 znaki palindromowe</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="81"/>
        <source>No more than %1 monotonic characters please</source>
        <translation>Nie więcej niż %1 znaki monotoniczne</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="82"/>
        <source>No more than %1 repeating characters please</source>
        <translation>Nie więcej niż %1 powtarzające się znaki</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="87"/>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>Hasło musi zawierać wielkie litery, małe litery, cyfry i symbole (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="88"/>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation>Hasło nie może zawierać więcej niż 4 znaki palindromowe</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="89"/>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="92"/>
        <source>Do not use common words and combinations as password</source>
        <translation>Nie używaj popularnych słów i ich kombinacji jako hasła</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="90"/>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="91"/>
        <source>Create a strong password please</source>
        <translation>Utwórz silne hasło</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="97"/>
        <source>It does not meet password rules</source>
        <translation>Nie spełnia zasad dotyczących haseł</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="43"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="49"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="59"/>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="44"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="45"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="46"/>
        <source>Key</source>
        <translation>Klucz</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="47"/>
        <source>key</source>
        <translation>klucz</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="55"/>
        <source>Private Pwd</source>
        <translation>Hasło prywatne</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="58"/>
        <source>Proxy Password</source>
        <translation>Hasło proxy</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="60"/>
        <source>Group Password</source>
        <translation>Hasło grupy</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/utils.h" line="71"/>
        <source>It cannot be empty</source>
        <translation>To pole nie może być puste</translation>
    </message>
</context>
<context>
    <name>ResetPasswordDialog</name>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="110"/>
        <source>Resetting the password will clear the data stored in the keyring</source>
        <translation>Zresetowanie hasła spowoduje usunięcie danych zapisanych w keyringu</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="112"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="168"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="210"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="121"/>
        <source>Security Questions</source>
        <translation>Pytania bezpieczeństwa</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="156"/>
        <source>Reset Password</source>
        <translation>Zresetuj hasło</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="157"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="195"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="198"/>
        <source>Next</source>
        <translation>Następna</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="160"/>
        <source>Reset Password By Union ID</source>
        <translation>Resetuj hasło poprzez Union ID</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="161"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="195"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="198"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="206"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="213"/>
        <source>Reset</source>
        <translation>Resetuj</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="167"/>
        <source>Resetting the password will clear the data stored in your keyring, and you should log in again, please save files in advance</source>
        <translation>Zresetowanie hasła wyczyści wszystkie dane przechowywane w Twoim keyringu, przez co wymagane będzie ponowne logowanie. Prosimy o zapisanie wszystkich danych przed kontynuowaniem</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="168"/>
        <source>Confirm and Reset</source>
        <translation>Potwierdź i resetuj</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="264"/>
        <source>Successfully reset, please log in and unlock with the new password</source>
        <translation>Hasło zostało zresetowane pomyślnie, proszę zaloguj się przy użyciu nowego hasła. </translation>
    </message>
</context>
<context>
    <name>SecurityQuestionsWidget</name>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="127"/>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="128"/>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="129"/>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="131"/>
        <source>What&apos;s the name of the city where you were born?</source>
        <translation>Jak nazywa się miasto, w którym się urodziłeś(aś)?</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="132"/>
        <source>What&apos;s the name of the first school you attended?</source>
        <translation>Jak nazywa się pierwsza szkoła, do której uczęszczałeś(aś)?</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="133"/>
        <source>Who do you love the most in this world?</source>
        <translation>Kogo kochasz najbardziej na świecie?</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="134"/>
        <source>What&apos;s your favorite animal?</source>
        <translation>Jakie jest twoje ulubione zwierzę?</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="135"/>
        <source>What&apos;s your favorite song?</source>
        <translation>Jaka jest twoja ulubiona piosenka?</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="136"/>
        <source>What&apos;s your nickname?</source>
        <translation>Jaka jest twoja ksywka?</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="186"/>
        <source>Wrong answer</source>
        <translation>Błędna odpowiedź</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="201"/>
        <source>Keep the answer under 30 characters</source>
        <translation>Utrzymaj odpowiedź w maksymalnie 30 znakach</translation>
    </message>
</context>
<context>
    <name>SuspendDialog</name>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="39"/>
        <source>External monitor detected, suspend?</source>
        <translation>Wykryto zewnętrzny monitor, czy chcesz go wstrzymać?</translation>
    </message>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="39"/>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="65"/>
        <source>%1s</source>
        <translation>%1s</translation>
    </message>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="54"/>
        <source>Suspend</source>
        <translation>Wstrzymaj</translation>
    </message>
</context>
<context>
    <name>TouchscreenSetting</name>
    <message>
        <location filename="../dde-touchscreen-dialog/src/touchscreensetting.cpp" line="45"/>
        <source>Select your touch screen</source>
        <translation>Wybierz ekran dotykowy</translation>
    </message>
    <message>
        <location filename="../dde-touchscreen-dialog/src/touchscreensetting.cpp" line="55"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../dde-touchscreen-dialog/src/touchscreensetting.cpp" line="56"/>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
</context>
<context>
    <name>UnionIDWidget</name>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="63"/>
        <source>Phone/Email</source>
        <translation>Telefon/E-mail</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="69"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="136"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="289"/>
        <source>Get Code</source>
        <translation>Zdobądź kod</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="89"/>
        <source>Connecting to the Internet...</source>
        <translation>Łączenie z Internetem...</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="101"/>
        <source>The user account is not linked to Union ID</source>
        <translation>Konto użytkownika nie jest powiązane z Union ID</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="114"/>
        <source>Network disconnected, please retry after connected</source>
        <translation>Brak połączenia z siecią, spróbuj ponownie po podłączeniu</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="134"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="135"/>
        <source>Required</source>
        <translation>Wymagane</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="170"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="185"/>
        <source>Phone/Email format is incorrect</source>
        <translation>Format Telefonu/E-mail jest nieprawidłowy</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="239"/>
        <source>System error</source>
        <translation>Błąd systemu</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="241"/>
        <source>Login expired, please sign in to the Union ID again</source>
        <translation>Sesja wygasła, zaloguj się ponownie do Union ID</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="243"/>
        <source>Network error</source>
        <translation>Błąd sieci</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="245"/>
        <source>You have reached the number limit to get the code today</source>
        <translation>Przekroczono dzienny limit kodów jednorazowych</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="246"/>
        <source>The Union ID is not linked to a user account</source>
        <translation>Union ID nie jest połączone z kontem użytkownika</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="255"/>
        <source>It cannot be empty</source>
        <translation>To pole nie może być puste</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="292"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="334"/>
        <source>Resend (%1s)</source>
        <translation>Wyślij ponownie (%1s)</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="353"/>
        <source>Failed to get the code</source>
        <translation>Nie udało się uzyskać kodu</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="376"/>
        <source>Wrong verification code</source>
        <translation>Nieprawidłowy kod weryfikacyjny</translation>
    </message>
</context>
<context>
    <name>UpdateContent</name>
    <message>
        <location filename="../dde-welcome/src/updatecontent.cpp" line="45"/>
        <source>Welcome, system updated successfully</source>
        <translation>Witamy, system został zaktualizowany pomyślnie</translation>
    </message>
    <message>
        <location filename="../dde-welcome/src/updatecontent.cpp" line="46"/>
        <source>Current Edition:</source>
        <translation>Obecne wydanie:</translation>
    </message>
    <message>
        <location filename="../dde-welcome/src/updatecontent.cpp" line="47"/>
        <source>Enter</source>
        <translation>Wprowadź</translation>
    </message>
</context>
<context>
    <name>WMChooser</name>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="57"/>
        <source>Effect Mode</source>
        <translation>Tryb efektów</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="60"/>
        <source>Normal Mode</source>
        <translation>Tryb normalny</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="68"/>
        <source>It has detected that you are using a virtual machine, which will affect the system performance and operation experience, for a smooth experience, Normal Mode is recommended</source>
        <translation>Wykryliśmy, że korzystasz z maszyny wirtualnej, która wpływa na wydajność systemu oraz jego działanie. Dla najlepszych doświadczeń, zalecamy wybór Trybu normalnego</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="71"/>
        <source>Effect Mode: Have a delicate experience. Normal Mode: Enjoy the fast performance</source>
        <translation>Tryb efektów: otrzymuj płynne i delikatne doznania. Tryb normalny: ciesz się wysoką wydajnością.</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="64"/>
        <source>Friendly Reminder</source>
        <translation>Przyjazne przypomnienie</translation>
    </message>
</context>
<context>
    <name>WarningDialog</name>
    <message>
        <location filename="../dde-warning-dialog/src/warningdialog.cpp" line="38"/>
        <source>Kindly Reminder</source>
        <translation>Uprzejme przypomnienie</translation>
    </message>
    <message>
        <location filename="../dde-warning-dialog/src/warningdialog.cpp" line="39"/>
        <source>This application cannot run without window effect</source>
        <translation>Ten program nie może działać bez efektów okien.</translation>
    </message>
    <message>
        <location filename="../dde-warning-dialog/src/warningdialog.cpp" line="43"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../dde-lowpower/src/window.cpp" line="41"/>
        <source>Low battery, please plug in</source>
        <translation>Niski poziom baterii, podłącz zasilanie</translation>
    </message>
</context>
</TS>